@@ -4,23 +4,21 @@ import stat
 import time
 from colorama import Fore, Style, init, deinit
 
+
 class Ls:
-    '''Docstring for Ls. This is a simple Python class for listing the content of a directory.
+    '''This is a simple Python class for listing the content of a directory.
     The sole purpose is giving portability to the common ls command to Windows systems'''
 
-    just = 6
+    just = 7
 
     def __init__(self, opt='', path='.') -> None:
 
-        if not opt:
-            self.opt, self.path = opt, path
-        elif opt.startswith('-'):
+        if not opt or opt.startswith('-'):
             self.opt, self.path = opt, path
         else:
             self.opt, self.path = '', opt
 
-    def echo(self, signal) -> None:
-        
+    def echo(self, signal: int) -> None:
         try:
             with os.scandir(self.path) as dir:
                 dir = sorted(dir, key=lambda x: (x.stat().st_mode, x.name))
@@ -29,55 +27,61 @@ class Ls:
                     for i in dir:
                         if i.name.startswith('.') and 'a' not in self.opt:
                             continue
-
-                        print(
-                            self.colorful_permissions(stat.filemode(i.stat().st_mode), 'c' in self.opt),
-                            time.strftime('%d %b %y %H:%M', time.localtime(i.stat().st_ctime)),
-                            self.human_color(self.humanize(i), 'c' in self.opt).rjust(self.just),
-                            self.type_color(i, 'c' in self.opt), sep='   ')
+                        
+                        # print() by 'column item' for better performance
+                        print(self._colorful_permissions(stat.filemode(i.stat().st_mode), 'c' in self.opt), end='   ')
+                        print(time.strftime('%d %b %y %H:%M', time.localtime(i.stat().st_ctime)), end='   ')
+                        print(self._human_color(self._humanize(i), 'c' in self.opt).rjust(self.just), end='   ')
+                        print(self._type_color(i, 'c' in self.opt))
 
                 else:
-                    print(*[self.type_color(i, 'c' in self.opt) for i in dir \
+                    print(*[self._type_color(i, 'c' in self.opt) for i in dir \
                         if not i.name.startswith('.') or 'a' in self.opt], sep='   ') 
-
+        except NotADirectoryError:
+            print(f'{self.path} is not a directory')
         except PermissionError as err:
             if signal: # not going recursively on echo()
+                print(f'{str(err)[:12]} {err.strerror}: {err.filename}')
                 deinit()
                 quit()
 
             try:
                 self.path = os.path.realpath(self.path)
                 self.echo(1)
-                print(f"\nYou can't access files from here because CD doesn't follow symlinks. Do first: cd {os.path.realpath('.')}")
-            except PermissionError:
-                print(err)
+                print(Style.RESET_ALL +
+                    f"\nYou can't access files from here because CD doesn't follow symlinks. Do first: cd {os.path.realpath('.')}"
+                    )
 
-    def type_color(self, i: os.DirEntry, colors: bool) -> str:
+            except PermissionError:
+                pass
+        
+        except FileNotFoundError as err:
+            print(err)
+
+    def _type_color(self, i: os.DirEntry, colors: bool) -> str:
         if not colors:
             return i.name
 
         #if i.is_symlink(): doesn't work
             
-        if i.is_dir():
-            if os.path.abspath(self.path).endswith('\\'): # workaround
-                if os.path.realpath(i.path) != os.path.abspath(self.path) + i.name: 
-                    return Fore.CYAN + i.name + Fore.LIGHTBLACK_EX + ' --> ' + os.path.realpath(i.path) + Style.RESET_ALL
-                return Fore.LIGHTBLUE_EX + i.name + Style.RESET_ALL
-                
-            elif os.path.realpath(i.path) != os.path.abspath(self.path) + f'\\{i.name}': 
-                return Fore.CYAN + i.name + Fore.LIGHTBLACK_EX + ' --> ' + os.path.realpath(i.path) + Style.RESET_ALL
-            return Fore.LIGHTBLUE_EX + i.name + Style.RESET_ALL
+        if i.is_dir():                
+            if os.path.realpath(i.path) != os.path.join(os.path.realpath(self.path), i.name): # workaround
+                return Fore.CYAN + i.name + Fore.LIGHTBLACK_EX + ' --> ' + os.path.realpath(i.path)
+
+            return Fore.LIGHTBLUE_EX + i.name
 
         else:
             if i.name.endswith(('.zip', '.exe', '.msi', '.dll', '.bat', '.sys', '.log', '.ini')):
-                return Fore.YELLOW + i.name + Style.RESET_ALL
+                return Fore.YELLOW + i.name
             if i.name.endswith(('.py', '.pyx', '.pyd', '.pyw')):
-                return Fore.GREEN + i.name + Style.RESET_ALL
+                return Fore.GREEN + i.name
             if i.name.endswith(('.tmp')):
-                return Fore.LIGHTBLACK_EX + i.name + Style.RESET_ALL
+                return Fore.LIGHTBLACK_EX + i.name
+            if i.name.endswith(('.pdf')):
+                return Fore.LIGHTRED_EX + i.name
             return i.name
 
-    def humanize(self, i: os.DirEntry):
+    def _humanize(self, i: os.DirEntry):
         if i.is_dir():
             return '-'
 
@@ -98,10 +102,11 @@ class Ls:
             return str(entry)
         return '-'
 
-    def human_color(self, data: str, colors: bool) -> str:
-        if not colors: return data
+    def _human_color(self, data: str, colors: bool) -> str:
+        if not colors:
+            return data
 
-        self.just = 15
+        self.just = 16
 
         if 'G' in data:
             return Fore.RED + data + Style.RESET_ALL
@@ -113,7 +118,7 @@ class Ls:
             return Fore.WHITE + data + Style.RESET_ALL
 
 
-    def colorful_permissions(self, data: os.stat_result.st_mode, colors: bool) -> str:
+    def _colorful_permissions(self, data: os.stat_result.st_mode, colors: bool) -> str:
         if not colors:
             return data
 
@@ -132,16 +137,14 @@ def main():
 
     args = sys.argv[1:]
 
-    #verificar caso haja portabilidade para unix
+    #For Powershell and Unix compatibility
     if len(args) > 2:
+        print(f'Ignored {sys.argv[3:]} parameter(s)')
         args = args[:2]
-        print(f'Ignored {sys.argv[3:]} parameters') 
 
-    obj = Ls(*args) if args else Ls()
-    
-    obj.echo(0)
+    Ls(*args).echo(0)
     deinit()
 
 
 if __name__ == '__main__':
-    main()
+    main()
\ No newline at end of file
